#
# spec file for package python-pycrypto
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pycrypto
Version:        2.5
Release:        22.1
Url:            http://www.pycrypto.org/
Summary:        Cryptographic modules for Python
License:        Python-2.0
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pycrypto/pycrypto-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gmp-devel
BuildRequires:  python-devel
Provides:       python-crypto = %{version}
Obsoletes:      python-crypto < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
The package contains:

  * Hash functions: MD2, MD4, RIPEMD, SHA256.
  * Block encryption algorithms: AES, ARC2, Blowfish, CAST, DES,
    Triple-DES, IDEA, RC5.
  * Stream encryption algorithms: ARC4, simple XOR.
  * Public-key algorithms: RSA, DSA, ElGamal, qNEW.
  * Protocols: All-or-nothing transforms, chaffing/winnowing.
  * Miscellaneous: RFC1751 module for converting 128-key keys into a
    set of English words, primality testing.
  * Some demo programs (currently all quite old and outdated).

%prep
%setup -q -n pycrypto-%{version}

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python setup.py test

%files
%defattr(-,root,root)
%doc ACKS ChangeLog COPYRIGHT README
%{python_sitearch}/Crypto/
%{python_sitearch}/pycrypto-%{version}-py*.egg-info

%changelog
* Mon Sep  3 2012 jengelh@inai.de
- Make package build on RH6-like systems
* Thu May 24 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 2.5:
  * Added PKCS#1 encryption schemes (v1.5 and OAEP).  We now have
    a decent, easy-to-use non-textbook RSA implementation.  Yay!
  * Added PKCS#1 signature schemes (v1.5 and PSS). v1.5 required some
    extensive changes to Hash modules to contain the algorithm specific
    ASN.1 OID. To that end, we now always have a (thin) Python module to
    hide the one in pure C.
  * Added 2 standard Key Derivation Functions (PBKDF1 and PBKDF2).
  * Added export/import of RSA keys in OpenSSH and PKCS#8 formats.
  * Added password-protected export/import of RSA keys (one old method
    for PKCS#8 PEM only).
  * Added ability to generate RSA key pairs with configurable public
    exponent e.
  * Added ability to construct an RSA key pair even if only the private
    exponent d is known, and not p and q.
  * Added SHA-2 C source code (fully from Lorenz Quack).
  * Unit tests for all the above.
  * Updates to documentation (both inline and in Doc/pycrypt.rst)
  * All of the above changes were put together by Legrandin (Thanks!)
  * Minor bug fixes (setup.py and tests).
- Changes from version 2.4.1:
  * Fix "error: Setup script exited with error: src/config.h: No such file or
    directory" when installing via easy_install.  (Sebastian Ramacher)
- Changes from version 2.4:
  * Python 3 support!  (Thorsten E. Behrens, Anders Sundman)
    PyCrypto now supports every version of Python from 2.1 through 3.2.
  * Timing-attack countermeasures in _fastmath: When built against
    libgmp version 5 or later, we use mpz_powm_sec instead of mpz_powm.
    This should prevent the timing attack described by Geremy Condra at
    PyCon 2011:
    http://blip.tv/pycon-us-videos-2009-2010-2011/pycon-2011-through-the-side-channel-timing-and-implementation-attacks-in-python-4897955
  * New hash modules (for Python >= 2.5 only): SHA224, SHA384, and
    SHA512 (Frédéric Bertolus)
  * Configuration using GNU autoconf.  This should help fix a bunch of
    build issues.
  * Support using MPIR as an alternative to GMP.
  * Improve the test command in setup.py, by allowing tests to be
    performed on a single sub-package or module only. (Legrandin)
  * Fix double-decref of "counter" when Cipher object initialisation
    fails (Ryan Kelly)
  * Apply patches from Debian's python-crypto 2.3-3 package (Jan
    Dittberner, Sebastian Ramacher):
  - fix-RSA-generate-exception.patch
  - epydoc-exclude-introspect.patch
  - no-usr-local.patch
  * Fix launchpad bug #702835: "Import key code is not compatible with
    GMP library" (Legrandin)
  * More tests, better documentation, various bugfixes.
* Thu Sep  1 2011 saschpe@suse.de
- Set license to Python-2.0, fixes bnc#715456
* Wed Aug 31 2011 saschpe@gmx.de
- Drop pycrypto-2.1.0-ssize.patch to fix SLE build
* Wed Aug 31 2011 saschpe@gmx.de
- Initial version, replaces python-crypto
